/////////////////////////////////////////////////////////////////////////////////////////////////////
// Created by Teneksi for Teneksi's vehicles
//
// SHOULD WORK WITH ANY WHEELED VEHICLES WITH THE FOLLOWING NODES
//   headlight0  (headlights off)
//   headlight1  (headlights on; glowing material)
//   brake0 (rear lights off)
//   brake1 (rear lights on, idle) 
//   brake2 (if animated with brakelight sequence; rear/brake lights on full)
//
//  If you use these nodes, this support file will make it so that the headlights and 
//  rear lights will turn on when there is a driver, and turn off when they exit the vehicle.
//  I use a brake0 and hide both brake1 and brake2 because the brakelight animation becomes stuck
//  on the second frame if a driver exits a vehicle while holding the brake.
//
// Previously I simply added the necessary functions to each vehicle I made, but I realized
// the list of "if (%col.getDatablock().getName() $= "whatever") could become lengthy.
// It felt sloppy and I was getting sick of copying the same package with different names.
// So, here it is. Credit to the writer of support_HandsOnVehicle for some of the structure.
//
//
// If you have the right nodes and want to use this, add the support script to your add-on folder
// Add the following line to the server.cs
//  exec("./support_DriverLights.cs");
// And the following line to the datablock of the vehicle that uses the nodes described
//  driverLightsCompatible = 1;
/////////////////////////////////////////////////////////////////////////////////////////////////////

if ($Server::DriverLightsSupportVersion > 2)
   return;			//If the current version is higher, don't continue executing this one.

$Server::DriverLightsSupportVersion = 2;	//Define this version as the current version.

if (isPackage(DriverLights))
{
	deactivatePackage(DriverLights);
}

package DriverLights
{
	function WheeledVehicleData::onAdd(%this, %obj)
	{
		Parent::onAdd(%this, %obj);
		if (%obj.getDatablock().driverLightsCompatible)
		{					//If the vehicle is compatible as indicated by the vehicle's author
			%obj.hidenode(headlight1);		//The vehicle should have these nodes as described above
			%obj.hidenode(brake1);
			%obj.hidenode(brake2);
		}
	}

	function armor::onUnMount(%this, %obj, %col, %slot)
	{
		Parent::onUnMount(%this, %obj, %col, %slot);

		if (!isObject(%col) || !%col.getDatablock().driverLightsCompatible)
			return;	//Do not try to continue if the vehicle has been deleted (or is not compatible)

		if (%obj.getMountNode() == 0)	//Turn off the lights, but only if it is the driver who left
		{
			%col.hideNode(brake1);	
			%col.hidenode(brake2);
			%col.hideNode(headlight1);
			%col.unhidenode(brake0);		//Values of 0 indicate "off" versions of lights
			%col.unhideNode(headlight0);
		}
	}
	function armor::onMount(%this, %obj, %col, %slot)
	{
		Parent::onMount(%this, %obj, %col, %slot);
		
		if (!%col.getDatablock().driverLightsCompatible)
			return;

		if (%obj.getMountNode() == 0)	//Turn on the lights, but only if a driver has been mounted
		{
			%col.unhideNode(brake1);
			%col.unhidenode(brake2);
			%col.unhideNode(headlight1);
			%col.hidenode(brake0);
			%col.hideNode(headlight0);
		}
	}
};
activatePackage(DriverLights);